#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 toml-parser
version:              2.0.2.0
visibility:           public
id:                   toml-parser-2.0.2.0-Bi3Z4Tf1Iqs6zcNkKqZpYT
key:                  toml-parser-2.0.2.0-Bi3Z4Tf1Iqs6zcNkKqZpYT
license:              ISC
copyright:            2023 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
synopsis:             TOML 1.1.0 parser
description:
    TOML parser using generated lexers and parsers with
    careful attention to the TOML 1.1.0 semantics for
    defining tables.

category:             Text
abi:                  07cc68e58958ff8ac9e465def9342659
exposed:              True
exposed-modules:
    Toml Toml.Pretty Toml.Schema Toml.Schema.FromValue
    Toml.Schema.Generic Toml.Schema.Generic.FromValue
    Toml.Schema.Generic.ToValue Toml.Schema.Matcher
    Toml.Schema.ParseTable Toml.Schema.ToValue Toml.Semantics
    Toml.Semantics.Ordered Toml.Semantics.Types Toml.Syntax
    Toml.Syntax.Lexer Toml.Syntax.Parser Toml.Syntax.Position
    Toml.Syntax.Token Toml.Syntax.Types

hidden-modules:       Toml.Syntax.LexerUtils Toml.Syntax.ParserUtils
import-dirs:          /usr/lib/ghc-9.6.6/site-local/toml-parser-2.0.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/toml-parser-2.0.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/toml-parser-2.0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-toml-parser
hs-libraries:         HStoml-parser-2.0.2.0-Bi3Z4Tf1Iqs6zcNkKqZpYT
depends:
    array-0.5.6.0 base-4.18.2.1 containers-0.6.7
    prettyprinter-1.7.1-EN3LFPJyyjtK4N4FJxxajw text-2.0.2 time-1.12.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-toml-parser/html/toml-parser.haddock
haddock-html:         /usr/share/doc/haskell-toml-parser/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

